@@ -20,6 +20,8 @@ from neutronclient.common import exceptions as n_exc
 from oslo_log import log as logging
 
 from kuryr_kubernetes import clients
+from kuryr_kubernetes import config
+from kuryr_kubernetes import constants
 from kuryr_kubernetes.controller.drivers import nested_vif
 from kuryr_kubernetes import exceptions as k_exc
 from kuryr_kubernetes import os_vif_util as ovu
@@ -46,7 +48,7 @@ class NestedVlanPodVIFDriver(nested_vif.NestedPodVIFDriver):
         return ovu.neutron_to_osvif_vif_nested_vlan(port, subnets, vlan_id)
 
     def request_vifs(self, pod, project_id, subnets, security_groups,
-                     num_ports):
+                     num_ports, trunk_ip=None):
         """This method creates subports and returns a list with their vifs.
 
         It creates up to num_ports subports and attaches them to the trunk
@@ -61,7 +63,10 @@ class NestedVlanPodVIFDriver(nested_vif.NestedPodVIFDriver):
         exception is raised.
         """
         neutron = clients.get_neutron_client()
-        parent_port = self._get_parent_port(neutron, pod)
+        if trunk_ip:
+            parent_port = self._get_parent_port_by_host_ip(neutron, trunk_ip)
+        else:
+            parent_port = self._get_parent_port(neutron, pod)
         trunk_id = self._get_trunk_id(parent_port)
 
         port_rq, subports_info = self._create_subports_info(
@@ -116,14 +121,17 @@ class NestedVlanPodVIFDriver(nested_vif.NestedPodVIFDriver):
     def _get_port_request(self, pod, project_id, subnets, security_groups,
                           unbound=False):
         port_req_body = {'project_id': project_id,
-                         'name': self._get_port_name(pod),
                          'network_id': self._get_network_id(subnets),
                          'fixed_ips': ovu.osvif_to_neutron_fixed_ips(subnets),
                          'device_owner': kl_const.DEVICE_OWNER,
                          'admin_state_up': True}
 
-        if unbound:
-            port_req_body['name'] = 'available-port'
+        # only set name if port_debug is enabled
+        if config.CONF.kubernetes.port_debug:
+            if unbound:
+                port_req_body['name'] = constants.KURYR_PORT_NAME
+            else:
+                port_req_body['name'] = self._get_port_name(pod)
 
         if security_groups:
             port_req_body['security_groups'] = security_groups
